@@ -66,6 +66,7 @@ typedef struct {
 	unsigned long  border_color;
 	int   test_pattern;
         int   is_override_redirect;
+        int   ignore_damage;
 } MagnifierOptions;
 
 static MagnifierOptions global_options = { ":0.0",
@@ -84,8 +85,8 @@ static MagnifierOptions global_options = { ":0.0",
 					   0,
 					   0,
 					   0,
-					   0,					   
-					   0,
+					   0,	
+                                   	   0,
 					   0,
 					   0,
 					   10,
@@ -95,6 +96,7 @@ static MagnifierOptions global_options = { ":0.0",
 					   0,
 					   0,
 					   0,
+					   0,
 					   0
                                          };
 
@@ -125,6 +127,7 @@ struct poptOption magnifier_options [] = {
 	{"border-color", 'c', POPT_ARG_LONG, &global_options.border_color, '\0', "border color specified as (A)RGB 23-bit value, Alpha-MSB", NULL},
 	{"use-test-pattern", '\0', POPT_ARG_NONE, &global_options.test_pattern, '\0', "use test pattern as source", NULL},
 	{"override-redirect", '\0', POPT_ARG_NONE, &global_options.is_override_redirect, '\0', "make the magnifier window totally unmanaged by the window manager", NULL},
+	{"ignore-damage", '\0', POPT_ARG_NONE, &global_options.ignore_damage, '\0', "ignore the X server DAMAGE extension, if present", NULL},
 	POPT_AUTOHELP
 	{NULL, 0, 0, NULL, 0, 0}
 };
@@ -385,6 +388,11 @@ main (int argc, char** argv)
   /* FIXME */
   gtk_init (&argc, &argv);
 
+  if (global_options.ignore_damage)
+  {
+      g_setenv ("MAGNIFIER_IGNORE_DAMAGE", "1", TRUE);
+  }
+
   magnifier = magnifier_new (global_options.is_override_redirect);
   fprintf (stderr, "New magnifier created.\n");
   
@@ -542,7 +550,8 @@ main (int argc, char** argv)
   }
   else
   {
-	  if (!magnifier_source_has_damage_extension (magnifier)) 
+	  if (global_options.ignore_damage ||
+	      !magnifier_source_has_damage_extension (magnifier)) 
 	  {
 		  refresh_handle = g_timeout_add (
 			  global_options.refresh_time,
