@@ -2361,6 +2361,17 @@ impl_zoom_region_set_roi (PortableServer_Servant servant,
 {
 	ZoomRegion *zoom_region =
 		ZOOM_REGION (bonobo_object_from_servant (servant));
+
+	/* if these bounds are clearly bogus, warn and ignore */
+	if (!bounds || (bounds->x2 <= bounds->x1)
+	    || (bounds->y2 < bounds->y1) || 
+	    ((bounds->x1 + bounds->x2)/2 < 0) || 
+	    ((bounds->y1 + bounds->y2)/2 < 0))
+	{
+	    g_warning ("Bad bounds request, ignoring.");
+	    return;
+	}
+
 	zoom_region->roi = *bounds;
 
 	if (zoom_region->timing_pan_rate > 0) {
